ALTER TABLE domains ADD COLUMN options VARCHAR(MAX) DEFAULT NULL;
ALTER TABLE domains ADD COLUMN catalog VARCHAR(255) DEFAULT NULL;
ALTER TABLE domains ALTER COLUMN type VARCHAR(8) NOT NULL;

CREATE INDEX catalog_idx ON domains(catalog);
